@@ -100,10 +100,12 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "BT", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "BW", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "CK", IgnoreRemark, Feature::NoFeature, Feature::Unknown }, // Komfort Check-in advertisment
+    { "A", "CR", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
     { "A", "EA", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "EF", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "EH", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "ER", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "EXTERNAL_ID", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     { "A", "FB", FeatureRemark, Feature::BikeStorage, Feature::Limited },
     { "A", "FK", FeatureRemark, Feature::BikeStorage, Feature::Limited },
     { "A", "FR", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
@@ -111,6 +113,7 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "G ", FeatureRemark, Feature::BikeStorage, Feature::Limited },
     { "A", "HD", FeatureRemark, Feature::SilentArea, Feature::Available },
     { "A", "HK", FeatureRemark, Feature::ToddlerArea, Feature::Available },
+    { "A", "JOURNEYNUMBER", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     { "A", "KG", FeatureRemark, Feature::Restaurant, Feature::Unavailable },
     { "A", "KK", FeatureRemark, Feature::ToddlerArea, Feature::Available },
     { "A", "KL", FeatureRemark, Feature::AirConditioning, Feature::Available },
@@ -118,6 +121,7 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "LS", FeatureRemark, Feature::PowerSockets, Feature::Available },
     { "A", "MN", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "MP", FeatureRemark, Feature::Restaurant, Feature::Available },
+    { "A", "NAME", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     { "A", "NF", FeatureRemark, Feature::BikeStorage, Feature::Unavailable },
     { "A", "OA", FeatureRemark, Feature::WheelchairAccessible, Feature::Conditional },
     { "A", "OC", FeatureRemark, Feature::WheelchairAccessibleToilet, Feature::Available },
@@ -129,20 +133,41 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "SA", FeatureRemark, Feature::ToddlerArea, Feature::Limited },
     { "A", "SI", FeatureRemark, Feature::WheelchairAccessible, Feature::Limited },
     { "A", "SN", FeatureRemark, Feature::Restaurant, Feature::Available },
+    { "A", "TD", FeatureRemark, Feature::WiFi, Feature::Available },
     { "A", "TM", FeatureRemark, Feature::Restaurant, Feature::Limited },
     { "A", "TO", FeatureRemark, Feature::Toilet, Feature::Available },
     { "A", "UA", FeatureRemark, Feature::BusinessArea, Feature::Available },
     { "A", "WI", FeatureRemark, Feature::WiFi, Feature::Available },
     { "A", "WV", FeatureRemark, Feature::WiFi, Feature::Available },
+    { "A", "ZB", FeatureRemark, Feature::WheelchairAccessible, Feature::Limited },
+    { "A", "ZM", FeatureRemark, Feature::WheelchairAccessible, Feature::Limited },
+    { "A", "aD", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "aR", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "aS", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "bV", FeatureRemark, Feature::Restaurant, Feature::Available },
+    { "A", "bW", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
     { "A", "bf", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "bg", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "de", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "df", FeatureRemark, Feature::WheelchairAccessible, Feature::Unavailable },
+    { "A", "dg", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "ei", FeatureRemark, Feature::BikeStorage, Feature::Available },
+    { "A", "ga", FeatureRemark, Feature::Restaurant, Feature::Available },
+    { "A", "gd", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "hz", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "ia", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "ic", FeatureRemark, Feature::Restaurant, Feature::Available },
+    { "A", "ie", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "kx", FeatureRemark, Feature::PowerSockets, Feature::Available },
+    { "A", "lb", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
    // ZVV: pointless note about checking intermediate stops for more details
     { "A", "moreAttr", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
+    { "A", "yh", FeatureRemark, Feature::WiFi, Feature::Available },
     { "A", "zd", OperatorRemark, Feature::NoFeature, Feature::Unknown },
     { "A", "zn", OperatorRemark, Feature::NoFeature, Feature::Unknown },
+    // pointless CO2 emission reduction ad
+    { "H", "text.connection.eco.co2.decreased.consumption.message", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
+    { "H", "vmt.accessible", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     // contains a pointless note about checking trip details
     { "H", "wagenstand_v2", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     // SBB line number?
