@@ -149,7 +149,6 @@ static Route parseRoute(const QJsonObject &lineObj)
 static void applyTimeZone(QDateTime &dt, const QTimeZone &tz)
 {
     if (dt.timeSpec() == Qt::OffsetFromUTC && tz.offsetFromUtc(dt) == dt.offsetFromUtc()) {
-        dt.setTimeSpec(Qt::TimeZone);
         dt.setTimeZone(tz);
     }
 }
@@ -349,11 +348,7 @@ std::vector<Journey> IvvAssParser::parseJourneys(const QByteArray &data)
             s.setDistance(segmentObj.value(QLatin1String("distance")).toInt());
             const auto polygon = segmentObj.value(QLatin1String("polygon")).toString();
             QPolygonF poly;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            const auto coords = polygon.splitRef(QLatin1Char(' '), Qt::SkipEmptyParts);
-#else
             const auto coords = QStringView(polygon).split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
             poly.reserve(coords.size());
             for (const auto &coord : coords) {
                 const auto p = coord.split(QLatin1Char(','));
