@@ -31,12 +31,10 @@ class KPUBLICTRANSPORT_EXPORT VehicleLayoutQueryModel : public AbstractQueryMode
     Q_PROPERTY(KPublicTransport::Platform platform READ platform NOTIFY contentChanged)
     /** The departure this vehicle layout belongs to. */
     Q_PROPERTY(KPublicTransport::Stopover stopover READ stopover NOTIFY contentChanged)
-    /** @deprecated use stopover. */
-    Q_PROPERTY(KPublicTransport::Stopover departure READ stopover NOTIFY contentChanged)
 
 public:
     explicit VehicleLayoutQueryModel(QObject *parent = nullptr);
-    ~VehicleLayoutQueryModel();
+    ~VehicleLayoutQueryModel() override;
 
     VehicleLayoutRequest request() const;
     void setRequest(const VehicleLayoutRequest &req);
@@ -44,7 +42,6 @@ public:
     Vehicle vehicle() const;
     Platform platform() const;
     Stopover stopover() const;
-    [[deprecated("use stopover()")]] Stopover departure() const;
 
     enum Roles {
         VehicleSectionRole = Qt::UserRole
